exceptiontools.ExtraNoteHeadError
=================================

.. abjad-lineage:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError

.. autoclass:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__unicode__
   :noindex:
